function sep_tracks = separate_trajs_into_consec_frames(tracks)
% Padding tracks so that the frame column is without gaps
% Author:
%   Yong Wang (c) Oct 2017
%
fprintf('sptPALM> padding tracks ...\n');
sep_tracks = [];
if size(tracks,1) < 1 %
    fprintf('sptPALM> the input <tracks> is empty! Cannot do padding.\n');
    return;
end

ntracks = max(tracks(:,4));
corrected_frm_num=1; % new frame num assigned to the beginning of each new trajectory

for i = 1:ntracks
    trk = tracks(tracks(:,4)==i,:);
    [frmin, jmin] = min(trk(:,3));
    [frmax, jmax] = max(trk(:,3));
    if jmin>1 || jmax<size(trk,1)
        fprintf('sptPALM> warning: it seems the tracks are not sorted!\n');    
    end
    n = (frmax-frmin+1);
    if n==size(trk,1) % no need to separate
        new_trk=trk; % inherit trk but...
        new_trk(:,4)=corrected_frm_num; % the last column (=traj ID) has to be updated
        sep_tracks = [sep_tracks; new_trk];
        corrected_frm_num=corrected_frm_num+1;
    else % pad
        gap=diff(trk(:,3));
        I_1=find(gap~=1);  % Find indexes of isolating points
        [n_ind,m_ind]=size(I_1);
        new_trk = trk; % saving new trajectories coming from 
                                    %separating trj by consecutive frames
        
        start_ind=1;  % set the start index
        for j=1:n_ind+1 % for the second run, ....
            if j == n_ind+1
                end_ind=jmax;
            else
                end_ind=I_1(j); 
            end
            % set end index
            new_trk(start_ind:end_ind, 4)=corrected_frm_num;
%            new_trk(end_ind:jmax,4)=corrected_frm_num+1; %separating into another trajectory 
            corrected_frm_num=corrected_frm_num+1;
            start_ind=end_ind+1;
        end
        sep_tracks = [sep_tracks; new_trk];

    end    
end
fprintf('sptPALM> done with padding tracks.\n');
end