function padded_tracks = sptPALM_pad_tracks_3d(tracks)
% Padding tracks so that the frame column is without gaps
% (x,y,z,f,id)
% Author:
%   Yong Wang (c) Oct 2017
%
fprintf('sptPALM> padding tracks ...\n');
padded_tracks = [];
if size(tracks,1) < 1 %
    fprintf('sptPALM> the input <tracks> is empty! Cannot do padding.\n');
    return;
end

ntracks = max(tracks(:,5));
for i = 1:ntracks
    trk = tracks(tracks(:,5)==i,:);
    [frmin, jmin] = min(trk(:,4));
    [frmax, jmax] = max(trk(:,4));
    if jmin>1 || jmax<size(trk,1)
        fprintf('sptPALM> warning: it seems the tracks are not sorted!\n');    
    end
    n = (frmax-frmin+1);
    if n==size(trk,1) % no need to pad
        padded_tracks = [padded_tracks; trk];
    else % pad
        fr = frmin:frmax;
        x = interp1(trk(:,4),trk(:,1),fr);
        y = interp1(trk(:,4),trk(:,2),fr);
        z = interp1(trk(:,4),trk(:,3),fr);
        new_trk = [reshape(x,[],1), reshape(y,[],1), reshape(z,[],1), reshape(fr,[],1),ones(n,1)*i];
        padded_tracks = [padded_tracks; new_trk];
    end  
end
fprintf('sptPALM> done with padding tracks.\n');
end